@@ -7,7 +7,7 @@ else:
     from pytextnow.multi_media_message import MultiMediaMessage
     from pytextnow.message import Message
 import mimetypes
-import requests
+import cloudscraper
 from datetime import datetime, time
 from dateutil.relativedelta import relativedelta
 
@@ -15,6 +15,7 @@ import json
 from os.path import realpath, dirname, join
 import time
 import atexit
+import re
 
 MESSAGE_TYPE = 0
 MULTIMEDIA_MESSAGE_TYPE = 1
@@ -24,6 +25,7 @@ RECEIVED_MESSAGE_TYPE = 1
 
 SIP_ENDPOINT = "prod.tncp.textnow.com"
 
+scraper = cloudscraper.create_scraper()
 
 class Client:
     def __init__(self, username: str = None, sid_cookie=None, csrf_cookie=None):
@@ -61,7 +63,7 @@ class Client:
                 with open(self._user_cookies_file, "w") as file:
                     file.write(json.dumps(self._user_cookies))
         else:
-            sid,csrf = sid_cookie,csrf_cookie if sid_cookie and csrf_cookie else login()
+            sid,csrf = (sid_cookie,csrf_cookie) if sid_cookie and csrf_cookie else login()
             self.cookies = {
                 'connect.sid': sid,
                 '_csrf': csrf,
@@ -92,12 +94,16 @@ class Client:
                         for msg in unread_msgs:
                             msg.mark_as_read()
                             func(msg)
+                time.sleep(1)
 
         atexit.register(on_exit)
 
     # Functions
+    def _replace_newlines(self, text):
+        return re.sub(r'(?<!\\)\n', r'\\n', text)
+
     def get_initial_csrf_token(self):
-        req = requests.get('https://www.textnow.com/messaging', cookies=self.cookies)
+        req = scraper.get('https://www.textnow.com/messaging', cookies=self.cookies)
 
         if req.status_code == 200:
             resp = req.text
@@ -138,13 +144,16 @@ class Client:
         """
             This gets most of the messages both sent and received. However It won't get all of them just the past 10-15
         """
-        req = requests.get("https://www.textnow.com/api/users/" + self.username + "/messages", headers=self.headers,
+        req = scraper.get("https://www.textnow.com/api/users/" + self.username + "/messages", headers=self.headers,
                            cookies=self.cookies)
+        
         if str(req.status_code).startswith("2"):
             messages = json.loads(req.content)
             messages = [
                 Message(msg, self) if not msg["message"].startswith("http") else MultiMediaMessage(msg, self)
                 for msg in messages["messages"]]
+            
+            time.sleep(1)
             return MessageContainer(messages, self)
         else:
             self.request_handler(req.status_code)
@@ -153,13 +162,15 @@ class Client:
         """
             This gets most of the messages both sent and received. However It won't get all of them just the past 10-15
         """
-        req = requests.get("https://www.textnow.com/api/users/" + self.username + "/messages", headers=self.headers,
+        req = scraper.get("https://www.textnow.com/api/users/" + self.username + "/messages", headers=self.headers,
                            cookies=self.cookies)
         if str(req.status_code).startswith("2"):
             messages = json.loads(req.content)
             return messages["messages"]
         else:
             self.request_handler(req.status_code)
+            
+        time.sleep(1)
 
     def get_sent_messages(self):
         """
@@ -167,7 +178,7 @@ class Client:
         """
         sent_messages = self.get_messages()
         sent_messages = [msg for msg in sent_messages if msg.direction == SENT_MESSAGE_TYPE]
-
+        time.sleep(1)
         return MessageContainer(sent_messages, self)
 
     def get_received_messages(self):
@@ -176,7 +187,7 @@ class Client:
         """
         messages = self.get_messages()
         messages = [msg for msg in messages if msg.direction == RECEIVED_MESSAGE_TYPE]
-
+        time.sleep(1)
         return MessageContainer(messages, self)
 
     def get_unread_messages(self):
@@ -185,7 +196,7 @@ class Client:
         """
         new_messages = self.get_received_messages()
         new_messages = [msg for msg in new_messages if not msg.read]
-
+        time.sleep(1)
         return MessageContainer(new_messages, self)
 
     def get_read_messages(self):
@@ -194,7 +205,7 @@ class Client:
         """
         new_messages = self.get_received_messages()
         new_messages = [msg for msg in new_messages if msg.read]
-
+        time.sleep(1)
         return MessageContainer(new_messages, self)
 
     def send_mms(self, to, file):
@@ -206,7 +217,7 @@ class Client:
         has_video = True if file_type == "video" else False
         msg_type = 2 if file_type is None else 2 if file_type == "image" else 4
 
-        file_url_holder_req = requests.get("https://www.textnow.com/api/v3/attachment_url?message_type=2",
+        file_url_holder_req = scraper.get("https://www.textnow.com/api/v3/attachment_url?message_type=2",
                                            cookies=self.cookies, headers=self.headers)
         if str(file_url_holder_req.status_code).startswith("2"):
             file_url_holder = json.loads(file_url_holder_req.text)["result"]
@@ -223,7 +234,7 @@ class Client:
                     "credentials": 'omit'
                 }
 
-                place_file_req = requests.put(file_url_holder, data=raw, headers=headers_place_file,
+                place_file_req = scraper.put(file_url_holder, data=raw, headers=headers_place_file,
                                               cookies=self.cookies)
                 if str(place_file_req.status_code).startswith("2"):
 
@@ -239,8 +250,10 @@ class Client:
                         "media_type": file_type
                     }
 
-                    send_file_req = requests.post("https://www.textnow.com/api/v3/send_attachment", data=json_data,
+                    send_file_req = scraper.post("https://www.textnow.com/api/v3/send_attachment", data=json_data,
                                                   headers=self.headers, cookies=self.cookies)
+                    
+                    time.sleep(1)
                     return send_file_req
                 else:
                     self.request_handler(place_file_req.status_code)
@@ -251,6 +264,8 @@ class Client:
         """
             Sends an sms text message to this number
         """
+        text = self._replace_newlines(text)
+        
         data = \
             {
                 'json': '{"contact_value":"' + to + '","contact_type":2,"message":"' + text + '","read":1,'
@@ -260,7 +275,7 @@ class Client:
                         self.username + '","has_video":false,"new":true,"date":"' + datetime.now().isoformat() + '"} '
             }
 
-        response = requests.post('https://www.textnow.com/api/users/' + self.username + '/messages',
+        response = scraper.post('https://www.textnow.com/api/users/' + self.username + '/messages',
                                  headers=self.headers, cookies=self.cookies, data=data)
 
         if response.status_code == 200:
@@ -270,6 +285,8 @@ class Client:
 
         if not str(response.status_code).startswith("2"):
             self.request_handler(response.status_code)
+            
+        time.sleep(1)
         return response
 
     def wait_for_response(self, number, timeout_bool=True):
