@@ -5,6 +5,6 @@ def login():
     print("Open application tab and copy connect.sid cookie and paste it here.")
     sid = input("connect.sid: ")
     print("Open application tab and copy _csrf cookie and paste it here.")
-    csrf = input("_csrf")
+    csrf = input("_csrf: ")
 
     return sid, csrf
