@@ -1,13 +1,14 @@
 from pytextnow.message import Message
-import requests
+import cloudscraper
 
 MULTIMEDIA_MESSAGE_TYPE = 1
 
+scraper = cloudscraper.create_scraper()
 
 class MultiMediaMessage(Message):
     def __init__(self, msg_obj, outer_self):
         super().__init__(msg_obj, outer_self)
-        file_req = requests.get(self.content)
+        file_req = scraper.get(self.content)
         self.raw_data = file_req.content
         self.content_type = file_req.headers["Content-Type"]
         self.extension = self.content_type.split("/")[1]
